# `fastwonn`

Fast, GPU-friendly, differentiable computation of Intrinsic Dimension via Maximum Likelihood (Levina & Bickel, 2004), the TwoNN algorithm (Facco et al., 2017), and everything in between!

---

### References
- [E. Levina, P. Bickel; "Maximum Likelihood Estimation of Intrinsic Dimension", Advances in Neural Information Processing Systems, 2004](https://papers.nips.cc/paper_files/paper/2004/hash/74934548253bcab8490ebd74afed7031-Abstract.html)
- [E. Facco, M. d'Errico, A. Rodriguez, A. Laio; "Estimating the intrinsic dimension of datasets by a minimal neighborhood information", Nature Scientific Reports, 2017](https://www.nature.com/articles/s41598-017-11873-y)
